@@ -7,12 +7,15 @@ namespace Icinga\Module\Icingadb\Controllers;
 use Exception;
 use GuzzleHttp\Psr7\ServerRequest;
 use Icinga\Application\Hook;
+use Icinga\Application\Icinga;
 use Icinga\Exception\IcingaException;
 use Icinga\Module\Icingadb\Compat\UrlMigrator;
 use Icinga\Module\Icingadb\Forms\SetAsBackendForm;
 use Icinga\Module\Icingadb\Hook\IcingadbSupportHook;
 use Icinga\Module\Icingadb\Web\Controller;
 use ipl\Html\HtmlString;
+use ipl\Stdlib\Filter;
+use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class MigrateController extends Controller
@@ -39,7 +42,7 @@ class MigrateController extends Controller
             $url = Url::fromPath($urlString);
             if (UrlMigrator::isSupportedUrl($url)) {
                 try {
-                    $urlString = UrlMigrator::transformUrl($url)->getAbsoluteUrl();
+                    $urlString = rawurldecode(UrlMigrator::transformUrl($url)->getAbsoluteUrl());
                 } catch (Exception $e) {
                     $errors[$urlString] = [
                         IcingaException::describe($e),
@@ -65,6 +68,38 @@ class MigrateController extends Controller
         $response->sendResponse();
     }
 
+    public function searchUrlAction()
+    {
+        $this->assertHttpMethod('post');
+        if (! $this->getRequest()->isApiRequest()) {
+            $this->httpBadRequest('No API request');
+        }
+
+        if (
+            ! preg_match('/([^;]*);?/', $this->getRequest()->getHeader('Content-Type'), $matches)
+            || $matches[1] !== 'application/json'
+        ) {
+            $this->httpBadRequest('No JSON content');
+        }
+
+        $urls = $this->getRequest()->getPost();
+
+        $result = [];
+        foreach ($urls as $urlString) {
+            $url = Url::fromPath($urlString);
+            $params = $url->onlyWith(['sort', 'limit', 'view', 'columns', 'page'])->getParams();
+            $filter = $url->without(['sort', 'limit', 'view', 'columns', 'page'])->getParams();
+            $filter = QueryString::parse((string) $filter);
+            $filter = UrlMigrator::transformLegacyWildcardFilter($filter);
+            $result[] = rawurldecode($url->setParams($params)->setFilter($filter)->getAbsoluteUrl());
+        }
+
+        $response = $this->getResponse()->json();
+        $response->setSuccessData($result);
+
+        $response->sendResponse();
+    }
+
     public function checkboxStateAction()
     {
         $this->assertHttpMethod('get');
@@ -97,18 +132,24 @@ class MigrateController extends Controller
             $this->httpBadRequest('No JSON content');
         }
 
-        $supportList = [];
-        foreach (Hook::all('Icingadb/IcingadbSupport') as $hook) {
-            /** @var IcingadbSupportHook $hook */
-            $supportList[$hook->getModule()->getName()] = $hook->supportsIcingaDb();
-        }
-
         $moduleSupportStates = [];
-        foreach ($this->getRequest()->getPost() as $moduleName) {
-            if (isset($supportList[$moduleName])) {
-                $moduleSupportStates[] = $supportList[$moduleName];
-            } else {
-                $moduleSupportStates[] = false;
+        if (
+            Icinga::app()->getModuleManager()->hasEnabled('monitoring')
+            && $this->Auth()->hasPermission('module/monitoring')
+        ) {
+            $supportList = [];
+            foreach (Hook::all('Icingadb/IcingadbSupport') as $hook) {
+                /** @var IcingadbSupportHook $hook */
+                $supportList[$hook->getModule()->getName()] = $hook->supportsIcingaDb();
+            }
+
+            $moduleSupportStates = [];
+            foreach ($this->getRequest()->getPost() as $moduleName) {
+                if (isset($supportList[$moduleName])) {
+                    $moduleSupportStates[] = $supportList[$moduleName];
+                } else {
+                    $moduleSupportStates[] = false;
+                }
             }
         }
 
