@@ -56,6 +56,6 @@ class CheckcommandEnvvar extends Model
     public function createRelations(Relations $relations)
     {
         $relations->belongsTo('environment', Environment::class);
-        $relations->belongsTo('checkcommand', CheckCommand::class);
+        $relations->belongsTo('checkcommand', Checkcommand::class);
     }
 }
