@@ -6,8 +6,8 @@ namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -83,7 +83,7 @@ class Comment extends Model
             'is_sticky'
         ]));
 
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'entry_time',
             'expire_time'
         ]));
@@ -108,13 +108,7 @@ class Comment extends Model
     {
         $relations->belongsTo('environment', Environment::class);
         $relations->belongsTo('host', Host::class)->setJoinType('LEFT');
-        $relations->belongsTo('host_state', HostState::class)
-            ->setForeignKey('last_comment_id')
-            ->setCandidateKey('id');
         $relations->belongsTo('service', Service::class)->setJoinType('LEFT');
-        $relations->belongsTo('service_state', ServiceState::class)
-            ->setForeignKey('last_comment_id')
-            ->setCandidateKey('id');
         $relations->belongsTo('zone', Zone::class);
     }
 }
