@@ -5,8 +5,8 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -79,7 +79,7 @@ class CommentHistory extends Model
             'has_been_removed'
         ]));
 
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'entry_time',
             'expire_time',
             'remove_time'
