@@ -5,8 +5,8 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -88,11 +88,10 @@ class DowntimeHistory extends Model
             'has_been_cancelled'
         ]));
 
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'entry_time',
             'scheduled_start_time',
             'scheduled_end_time',
-            'flexible_duration',
             'start_time',
             'end_time',
             'trigger_time',
