@@ -4,8 +4,8 @@
 
 namespace Icinga\Module\Icingadb\Model;
 
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -64,7 +64,7 @@ class FlappingHistory extends Model
 
     public function createBehaviors(Behaviors $behaviors)
     {
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'start_time',
             'end_time'
         ]));
