@@ -5,8 +5,8 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -63,12 +63,12 @@ class History extends Model
 
     public function getDefaultSort()
     {
-        return 'history.event_time desc';
+        return 'history.event_time desc, history.event_type desc';
     }
 
     public function createBehaviors(Behaviors $behaviors)
     {
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'event_time'
         ]));
 
