@@ -121,7 +121,7 @@ class Host extends Model
 
     public function getSearchColumns()
     {
-        return ['name_ci'];
+        return ['name_ci', 'display_name'];
     }
 
     public function getDefaultSort()
@@ -199,7 +199,8 @@ class Host extends Model
         $relations->belongsTo('eventcommand', Eventcommand::class);
         $relations->belongsTo('checkcommand', Checkcommand::class);
         $relations->belongsTo('timeperiod', Timeperiod::class)
-            ->setCandidateKey('check_timeperiod_id');
+            ->setCandidateKey('check_timeperiod_id')
+            ->setJoinType('LEFT');
         $relations->belongsTo('action_url', ActionUrl::class)
             ->setCandidateKey('action_url_id')
             ->setForeignKey('id');
