@@ -50,7 +50,7 @@ class Hostgroup extends Model
 
     public function getSearchColumns()
     {
-        return ['name_ci'];
+        return ['name_ci', 'display_name'];
     }
 
     public function getDefaultSort()
