@@ -5,8 +5,8 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
-use Icinga\Module\Icingadb\Model\Behavior\Timestamp;
 use ipl\Orm\Behavior\Binary;
+use ipl\Orm\Behavior\MillisecondTimestamp;
 use ipl\Orm\Behaviors;
 use ipl\Orm\Model;
 use ipl\Orm\Relations;
@@ -80,7 +80,7 @@ class NotificationHistory extends Model
 
     public function createBehaviors(Behaviors $behaviors)
     {
-        $behaviors->add(new Timestamp([
+        $behaviors->add(new MillisecondTimestamp([
             'send_time'
         ]));
 
@@ -107,6 +107,7 @@ class NotificationHistory extends Model
             ->setForeignKey('notification_history_id');
         $relations->belongsTo('host', Host::class);
         $relations->belongsTo('service', Service::class)->setJoinType('LEFT');
+        $relations->belongsTo('notification', Notification::class)->setJoinType('LEFT');
 
         $relations->belongsToMany('user', User::class)
             ->through('user_notification_history');
