@@ -58,27 +58,17 @@ class ServiceState extends State
     {
         $relations->belongsTo('environment', Environment::class);
         $relations->belongsTo('service', Service::class);
-        $relations->hasOne('last_comment', Comment::class)
+        $relations->hasOne('last_comment', LastServiceComment::class)
             ->setCandidateKey('last_comment_id')
             ->setForeignKey('id')
             ->setJoinType('LEFT');
     }
 
-    /**
-     * Get the host state as the textual representation
-     *
-     * @return string
-     */
     public function getStateText(): string
     {
         return ServiceStates::text($this->soft_state);
     }
 
-    /**
-     * Get the host state as the translated textual representation
-     *
-     * @return string
-     */
     public function getStateTextTranslated(): string
     {
         return ServiceStates::text($this->soft_state);
