@@ -63,7 +63,7 @@ class User extends Model
 
     public function getSearchColumns()
     {
-        return ['name_ci'];
+        return ['name_ci', 'display_name'];
     }
 
     public function getDefaultSort()
