@@ -148,7 +148,7 @@ class ObjectSuggestions extends Suggestions
         }
 
         $columnPath = $query->getResolver()->qualifyPath($column, $model->getTableName());
-        list($targetPath, $columnName) = preg_split('/(?<=vars)\.|\.(?=[^.]+$)/', $columnPath);
+        list($targetPath, $columnName) = preg_split('/(?<=vars)\.|\.(?=[^.]+$)/', $columnPath, 2);
 
         $isCustomVar = false;
         if (substr($targetPath, -5) === '.vars') {
@@ -212,15 +212,16 @@ class ObjectSuggestions extends Suggestions
 
         // Custom variables only after the columns are exhausted and there's actually a chance the user sees them
         $titleAdded = false;
+        $parsedArrayVars = [];
         foreach ($this->getDb()->select($this->queryCustomvarConfig($searchTerm)) as $customVar) {
             $search = $name = $customVar->flatname;
-            if (preg_match('/\w+\[(\d+)]$/', $search, $matches)) {
-                // array vars need to be specifically handled
-                if ($matches[1] !== '0') {
+            if (preg_match('/\w+(?:\[(\d*)])+$/', $search, $matches)) {
+                $name = substr($search, 0, -(strlen($matches[1]) + 2));
+                if (isset($parsedArrayVars[$name])) {
                     continue;
                 }
 
-                $name = substr($search, 0, -3);
+                $parsedArrayVars[$name] = true;
                 $search = $name . '[*]';
             }
 
@@ -320,8 +321,8 @@ class ObjectSuggestions extends Suggestions
             self::collectRelations($resolver, $model, $models, []);
         }
 
+        /** @var Model $targetModel */
         foreach ($models as $path => $targetModel) {
-            /** @var Model $targetModel */
             foreach ($resolver->getColumnDefinitions($targetModel) as $columnName => $definition) {
                 yield $path . '.' . $columnName => $definition->getLabel();
             }
@@ -384,10 +385,15 @@ class ObjectSuggestions extends Suggestions
     {
         foreach ($resolver->getRelations($subject) as $name => $relation) {
             /** @var Relation $relation */
-            $isHasOne = $relation instanceof HasOne;
-            if (empty($path) || $name === 'state' || $name === 'last_comment') {
+            if (
+                empty($path) || (
+                    ($name === 'state' && $path[count($path) - 1] !== 'last_comment')
+                    || $name === 'last_comment'
+                    || $name === 'notificationcommand' && $path[0] === 'notification'
+                )
+            ) {
                 $relationPath = [$name];
-                if ($isHasOne && empty($path)) {
+                if ($relation instanceof HasOne && empty($path)) {
                     array_unshift($relationPath, $subject->getTableName());
                 }
 
