@@ -11,18 +11,20 @@ use Icinga\Application\Config;
 use Icinga\Application\Icinga;
 use Icinga\Application\Logger;
 use Icinga\Application\Version;
+use Icinga\Application\Web;
 use Icinga\Data\ConfigObject;
 use Icinga\Date\DateFormatter;
 use Icinga\Exception\ConfigurationError;
+use Icinga\Exception\Http\HttpBadRequestException;
 use Icinga\Exception\Json\JsonDecodeException;
 use Icinga\Module\Icingadb\Common\Auth;
 use Icinga\Module\Icingadb\Common\Database;
-use Icinga\Module\Icingadb\Common\BaseItemList;
 use Icinga\Module\Icingadb\Common\SearchControls;
 use Icinga\Module\Icingadb\Data\CsvResultSet;
 use Icinga\Module\Icingadb\Data\JsonResultSet;
+use Icinga\Module\Icingadb\Web\Control\GridViewModeSwitcher;
 use Icinga\Module\Icingadb\Web\Control\ViewModeSwitcher;
-use Icinga\Module\Icingadb\Widget\ItemTable\BaseItemTable;
+use Icinga\Module\Icingadb\Widget\ItemTable\StateItemTable;
 use Icinga\Module\Pdfexport\PrintableHtmlDocument;
 use Icinga\Module\Pdfexport\ProvidedHook\Pdfexport;
 use Icinga\Security\SecurityException;
@@ -34,12 +36,12 @@ use ipl\Html\Html;
 use ipl\Html\ValidHtml;
 use ipl\Orm\Query;
 use ipl\Orm\UnionQuery;
-use ipl\Stdlib\Contract\Paginatable;
 use ipl\Stdlib\Filter;
+use ipl\Web\Common\BaseItemList;
+use ipl\Web\Common\BaseItemTable;
 use ipl\Web\Compat\CompatController;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\PaginationControl;
-use ipl\Web\Control\SortControl;
 use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
@@ -72,12 +74,27 @@ class Controller extends CompatController
         return $this->filter;
     }
 
-    public function createColumnControl(Query $query, ViewModeSwitcher $viewModeSwitcher)
+    /**
+     * Create column control
+     *
+     * @param Query $query
+     * @param ViewModeSwitcher $viewModeSwitcher
+     *
+     * @return array provided columns
+     *
+     * @throws HttpBadRequestException
+     */
+    public function createColumnControl(Query $query, ViewModeSwitcher $viewModeSwitcher): array
     {
         // All of that is essentially what `ColumnControl::apply()` should do
+        $viewMode = $this->getRequest()->getUrl()->getParam($viewModeSwitcher->getViewModeParam());
         $columnsDef = $this->params->shift('columns');
         if (! $columnsDef) {
-            return null;
+            if ($viewMode === 'tabular') {
+                $this->httpBadRequest('Missing parameter "columns"');
+            }
+
+            return [];
         }
 
         $columns = [];
@@ -89,7 +106,7 @@ class Controller extends CompatController
 
         $query->withColumns($columns);
 
-        if (! $this->getRequest()->getUrl()->hasParam($viewModeSwitcher->getViewModeParam())) {
+        if (! $viewMode) {
             $viewModeSwitcher->setViewMode('tabular');
         }
 
@@ -98,61 +115,6 @@ class Controller extends CompatController
         return $columns;
     }
 
-    /**
-     * Create and return the LimitControl
-     *
-     * This automatically shifts the limit URL parameter from {@link $params}.
-     *
-     * @return LimitControl
-     */
-    public function createLimitControl(): LimitControl
-    {
-        $limitControl = new LimitControl(Url::fromRequest());
-        $limitControl->setDefaultLimit($this->getPageSize(null));
-
-        $this->params->shift($limitControl->getLimitParam());
-
-        return $limitControl;
-    }
-
-    /**
-     * Create and return the PaginationControl
-     *
-     * This automatically shifts the pagination URL parameters from {@link $params}.
-     *
-     * @return PaginationControl
-     */
-    public function createPaginationControl(Paginatable $paginatable): PaginationControl
-    {
-        $paginationControl = new PaginationControl($paginatable, Url::fromRequest());
-        $paginationControl->setDefaultPageSize($this->getPageSize(null));
-        $paginationControl->setAttribute('id', $this->getRequest()->protectId('pagination-control'));
-
-        $this->params->shift($paginationControl->getPageParam());
-        $this->params->shift($paginationControl->getPageSizeParam());
-
-        return $paginationControl->apply();
-    }
-
-    /**
-     * Create and return the SortControl
-     *
-     * This automatically shifts the sort URL parameter from {@link $params}.
-     *
-     * @param Query $query
-     * @param array $columns Possible sort columns as sort string-label pairs
-     *
-     * @return SortControl
-     */
-    public function createSortControl(Query $query, array $columns): SortControl
-    {
-        $sortControl = SortControl::create($columns);
-
-        $this->params->shift($sortControl->getSortParam());
-
-        return $sortControl->apply($query);
-    }
-
     /**
      * Create and return the ViewModeSwitcher
      *
@@ -162,14 +124,22 @@ class Controller extends CompatController
      * @param LimitControl      $limitControl
      * @param bool              $verticalPagination
      *
-     * @return ViewModeSwitcher
+     * @return ViewModeSwitcher|GridViewModeSwitcher
      */
     public function createViewModeSwitcher(
         PaginationControl $paginationControl,
         LimitControl $limitControl,
         bool $verticalPagination = false
     ): ViewModeSwitcher {
-        $viewModeSwitcher = new ViewModeSwitcher();
+        $controllerName = $this->getRequest()->getControllerName();
+
+        // TODO: Make this configurable somehow. The route shouldn't be checked to choose the view modes!
+        if ($controllerName === 'hostgroups' || $controllerName === 'servicegroups') {
+            $viewModeSwitcher = new GridViewModeSwitcher();
+        } else {
+            $viewModeSwitcher = new ViewModeSwitcher();
+        }
+
         $viewModeSwitcher->setIdProtector([$this->getRequest(), 'protectId']);
 
         $user = $this->Auth()->getUser();
@@ -237,7 +207,7 @@ class Controller extends CompatController
 
                 $requestUrl->setParam($viewModeSwitcher->getViewModeParam(), $viewMode);
                 if (! $requestUrl->hasParam($limitParam)) {
-                    if ($viewMode === 'minimal') {
+                    if ($viewMode === 'minimal' || $viewMode === 'grid') {
                         $session->set('previous_page', $currentPage);
                         $session->set('request_path', $requestUrl->getPath());
 
@@ -250,7 +220,10 @@ class Controller extends CompatController
                         }
 
                         $session->set('current_page', $currentPage);
-                    } elseif ($viewModeSwitcher->getDefaultViewMode() === 'minimal') {
+                    } elseif (
+                        $viewModeSwitcher->getDefaultViewMode() === 'minimal'
+                        || $viewModeSwitcher->getDefaultViewMode() === 'grid'
+                    ) {
                         $limit = $paginationControl->getLimit();
                         if ($currentPage === $session->get('current_page')) {
                             // No other page numbers have been selected, i.e the user only
@@ -276,7 +249,8 @@ class Controller extends CompatController
             }
         )->handleRequest(ServerRequest::fromGlobals());
 
-        if ($viewModeSwitcher->getViewMode() === 'minimal') {
+        $viewMode = $viewModeSwitcher->getViewMode();
+        if ($viewMode === 'minimal' || $viewMode === 'grid') {
             $hasLimitParam = Url::fromRequest()->hasParam($limitControl->getLimitParam());
 
             if ($paginationControl->getDefaultPageSize() <= LimitControl::DEFAULT_LIMIT && ! $hasLimitParam) {
@@ -299,10 +273,11 @@ class Controller extends CompatController
      * Process a search request
      *
      * @param Query $query
+     * @param array $additionalColumns
      *
      * @return void
      */
-    public function handleSearchRequest(Query $query)
+    public function handleSearchRequest(Query $query, array $additionalColumns = [])
     {
         $q = trim($this->params->shift('q', ''), ' *');
         if (! $q) {
@@ -310,13 +285,10 @@ class Controller extends CompatController
         }
 
         $filter = Filter::any();
-        $this->prepareSearchFilter($query, $q, $filter);
+        $this->prepareSearchFilter($query, $q, $filter, $additionalColumns);
 
         $redirectUrl = Url::fromRequest();
-        $redirectUrl->setQueryString(QueryString::render($filter));
-        foreach ($this->params->toArray(false) as $name => $value) {
-            $redirectUrl->getParams()->addEncoded($name, $value);
-        }
+        $redirectUrl->setParams($this->params)->setFilter($filter);
 
         $this->getResponse()->redirectAndExit($redirectUrl);
     }
@@ -327,12 +299,14 @@ class Controller extends CompatController
      * @param Query $query
      * @param string $search
      * @param Filter\Any $filter
+     * @param array $additionalColumns
      *
      * @return void
      */
-    protected function prepareSearchFilter(Query $query, string $search, Filter\Any $filter)
+    protected function prepareSearchFilter(Query $query, string $search, Filter\Any $filter, array $additionalColumns)
     {
-        foreach ($query->getModel()->getSearchColumns() as $column) {
+        $columns = array_merge($query->getModel()->getSearchColumns(), $additionalColumns);
+        foreach ($columns as $column) {
             $filter->add(Filter::like(
                 $query->getResolver()->qualifyColumn($column, $query->getModel()->getTableName()),
                 "*$search*"
@@ -452,7 +426,7 @@ class Controller extends CompatController
         $time = DateFormatter::formatDateTime(time());
 
         $doc = (new PrintableHtmlDocument())
-            ->setTitle($this->view->title)
+            ->setTitle($this->view->title ?? '')
             ->setHeader(Html::wantHtml([
                 Html::tag('span', ['class' => 'title']),
                 Html::tag('time', null, $time)
@@ -508,9 +482,9 @@ class Controller extends CompatController
 
     protected function addContent(ValidHtml $content)
     {
-        if ($content instanceof BaseItemList) {
+        if ($content instanceof BaseItemList || $content instanceof BaseItemTable) {
             $this->content->getAttributes()->add('class', 'full-width');
-        } elseif ($content instanceof BaseItemTable) {
+        } elseif ($content instanceof StateItemTable) {
             $this->content->getAttributes()->add('class', 'full-height');
         }
 
@@ -559,7 +533,9 @@ class Controller extends CompatController
 
     protected function moduleInit()
     {
-        Icinga::app()->getFrontController()
+        /** @var Web $app */
+        $app = Icinga::app();
+        $app->getFrontController()
             ->getPlugin('Zend_Controller_Plugin_ErrorHandler')
             ->setErrorHandlerModule('icingadb');
     }
