@@ -25,11 +25,12 @@ use Icinga\Module\Icingadb\Model\History;
 use Icinga\Module\Icingadb\Model\NotificationHistory;
 use Icinga\Module\Icingadb\Model\StateHistory;
 use Icinga\Module\Icingadb\Util\PluginOutput;
-use Icinga\Module\Icingadb\Widget\EmptyState;
-use ipl\Web\Widget\HorizontalKeyValue;
-use Icinga\Module\Icingadb\Widget\ItemList\UserList;
-use Icinga\Module\Icingadb\Widget\PluginOutputContainer;
 use Icinga\Module\Icingadb\Widget\ShowMore;
+use ipl\Web\Widget\CopyToClipboard;
+use ipl\Web\Widget\EmptyState;
+use ipl\Web\Widget\HorizontalKeyValue;
+use Icinga\Module\Icingadb\Widget\ItemTable\UserTable;
+use Icinga\Module\Icingadb\Widget\PluginOutputContainer;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\FormattedString;
 use ipl\Html\HtmlElement;
@@ -79,6 +80,8 @@ class EventDetail extends BaseHtmlElement
                             ? $this->event->host->checkcommand_name
                             : $this->event->service->checkcommand_name)
                 );
+
+                CopyToClipboard::attachTo($notificationText);
             }
 
             $pluginOutput = [
@@ -121,7 +124,10 @@ class EventDetail extends BaseHtmlElement
 
         $eventInfo = [
             new HtmlElement('h2', null, Text::create(t('Event Info'))),
-            new HorizontalKeyValue(t('Sent On'), DateFormatter::formatDateTime($notification->send_time))
+            new HorizontalKeyValue(
+                t('Sent On'),
+                DateFormatter::formatDateTime($notification->send_time->getTimestamp())
+            )
         ];
 
         if ($notification->author) {
@@ -156,7 +162,7 @@ class EventDetail extends BaseHtmlElement
             $users = $users->execute();
             /** @var ResultSet $users */
 
-            $notifiedUsers[] = new UserList($users);
+            $notifiedUsers[] = new UserTable($users);
             $notifiedUsers[] = (new ShowMore(
                 $users,
                 Links::users()->addParams(['notification_history.id' => bin2hex($notification->id)]),
@@ -186,6 +192,8 @@ class EventDetail extends BaseHtmlElement
                     (new PluginOutput($stateChange->output . "\n" . $stateChange->long_output))
                         ->setCommandName($commandName)
                 );
+
+                CopyToClipboard::attachTo($commandOutput);
             }
 
             $pluginOutput = [
@@ -230,7 +238,10 @@ class EventDetail extends BaseHtmlElement
 
         $eventInfo = [
             new HtmlElement('h2', null, Text::create(t('Event Info'))),
-            new HorizontalKeyValue(t('Occurred On'), DateFormatter::formatDateTime($stateChange->event_time)),
+            new HorizontalKeyValue(
+                t('Occurred On'),
+                DateFormatter::formatDateTime($stateChange->event_time->getTimestamp())
+            ),
             new HorizontalKeyValue(t('Scheduling Source'), $stateChange->scheduling_source),
             new HorizontalKeyValue(t('Check Source'), $stateChange->check_source)
         ];
@@ -319,29 +330,38 @@ class EventDetail extends BaseHtmlElement
                     HtmlElement::create('span', ['class' => 'subject'], $this->event->host->display_name)
                 )
             ));
-        $eventInfo[] = new HorizontalKeyValue(t('Entered On'), DateFormatter::formatDateTime($downtime->entry_time));
+        $eventInfo[] = new HorizontalKeyValue(
+            t('Entered On'),
+            DateFormatter::formatDateTime($downtime->entry_time->getTimestamp())
+        );
         $eventInfo[] = new HorizontalKeyValue(t('Author'), [new Icon('user'), $downtime->author]);
             // TODO: The following should be presented in a specific widget (maybe just like the downtime card)
         $eventInfo[] = new HorizontalKeyValue(
             t('Triggered On'),
-            DateFormatter::formatDateTime($downtime->trigger_time)
+            DateFormatter::formatDateTime($downtime->trigger_time->getTimestamp())
         );
         $eventInfo[] = new HorizontalKeyValue(
             t('Scheduled Start'),
-            DateFormatter::formatDateTime($downtime->scheduled_start_time)
+            DateFormatter::formatDateTime($downtime->scheduled_start_time->getTimestamp())
+        );
+        $eventInfo[] = new HorizontalKeyValue(
+            t('Actual Start'),
+            DateFormatter::formatDateTime($downtime->start_time->getTimestamp())
         );
-        $eventInfo[] = new HorizontalKeyValue(t('Actual Start'), DateFormatter::formatDateTime($downtime->start_time));
         $eventInfo[] = new HorizontalKeyValue(
             t('Scheduled End'),
-            DateFormatter::formatDateTime($downtime->scheduled_end_time)
+            DateFormatter::formatDateTime($downtime->scheduled_end_time->getTimestamp())
+        );
+        $eventInfo[] = new HorizontalKeyValue(
+            t('Actual End'),
+            DateFormatter::formatDateTime($downtime->end_time->getTimestamp())
         );
-        $eventInfo[] = new HorizontalKeyValue(t('Actual End'), DateFormatter::formatDateTime($downtime->end_time));
 
         if ($downtime->is_flexible) {
             $eventInfo[] = new HorizontalKeyValue(t('Flexible'), t('Yes'));
             $eventInfo[] = new HorizontalKeyValue(
                 t('Duration'),
-                DateFormatter::formatDuration($downtime->flexible_duration)
+                DateFormatter::formatDuration($downtime->flexible_duration / 1000)
             );
         }
 
@@ -349,7 +369,10 @@ class EventDetail extends BaseHtmlElement
         if ($downtime->has_been_cancelled) {
             $cancelInfo = [
                 new HtmlElement('h2', null, Text::create(t('This downtime has been cancelled'))),
-                new HorizontalKeyValue(t('Cancelled On'), DateFormatter::formatDateTime($downtime->cancel_time)),
+                new HorizontalKeyValue(
+                    t('Cancelled On'),
+                    DateFormatter::formatDateTime($downtime->cancel_time->getTimestamp())
+                ),
                 new HorizontalKeyValue(t('Cancelled by'), [new Icon('user'), $downtime->cancelled_by])
             ];
         }
@@ -385,12 +408,15 @@ class EventDetail extends BaseHtmlElement
                     HtmlElement::create('span', ['class' => 'subject'], $this->event->host->display_name)
                 )
             ));
-        $eventInfo[] = new HorizontalKeyValue(t('Entered On'), DateFormatter::formatDateTime($comment->entry_time));
+        $eventInfo[] = new HorizontalKeyValue(
+            t('Entered On'),
+            DateFormatter::formatDateTime($comment->entry_time->getTimestamp())
+        );
         $eventInfo[] = new HorizontalKeyValue(t('Author'), [new Icon('user'), $comment->author]);
         $eventInfo[] = new HorizontalKeyValue(
             t('Expires On'),
             $comment->expire_time
-                ? DateFormatter::formatDateTime($comment->expire_time)
+                ? DateFormatter::formatDateTime($comment->expire_time->getTimestamp())
                 : new EmptyState(t('Never'))
         );
 
@@ -409,7 +435,7 @@ class EventDetail extends BaseHtmlElement
             if ($comment->removed_by) {
                 $removedInfo[] = new HorizontalKeyValue(
                     t('Removed On'),
-                    DateFormatter::formatDateTime($comment->remove_time)
+                    DateFormatter::formatDateTime($comment->remove_time->getTimestamp())
                 );
                 $removedInfo[] = new HorizontalKeyValue(
                     t('Removed by'),
@@ -418,7 +444,7 @@ class EventDetail extends BaseHtmlElement
             } else {
                 $removedInfo[] = new HorizontalKeyValue(
                     t('Expired On'),
-                    DateFormatter::formatDateTime($comment->remove_time)
+                    DateFormatter::formatDateTime($comment->remove_time->getTimestamp())
                 );
             }
         }
@@ -450,7 +476,10 @@ class EventDetail extends BaseHtmlElement
                         HtmlElement::create('span', ['class' => 'subject'], $this->event->host->display_name)
                     )
                 )),
-            new HorizontalKeyValue(t('Started on'), DateFormatter::formatDateTime($flapping->start_time))
+            new HorizontalKeyValue(
+                t('Started on'),
+                DateFormatter::formatDateTime($flapping->start_time->getTimestamp())
+            )
         ];
         if ($this->event->event_type === 'flapping_start') {
             $eventInfo[] = new HorizontalKeyValue(t('Reason'), sprintf(
@@ -459,7 +488,10 @@ class EventDetail extends BaseHtmlElement
                 $flapping->flapping_threshold_high
             ));
         } else {
-            $eventInfo[] = new HorizontalKeyValue(t('Ended on'), DateFormatter::formatDateTime($flapping->end_time));
+            $eventInfo[] = new HorizontalKeyValue(
+                t('Ended on'),
+                DateFormatter::formatDateTime($flapping->end_time->getTimestamp())
+            );
             $eventInfo[] = new HorizontalKeyValue(t('Reason'), sprintf(
                 t('State change rate of %.2f%% undercut the threshold (%.2f%%)'),
                 $flapping->percent_state_change_end,
@@ -486,7 +518,10 @@ class EventDetail extends BaseHtmlElement
 
         $eventInfo = [
             new HtmlElement('h2', null, Text::create(t('Event Info'))),
-            new HorizontalKeyValue(t('Set on'), DateFormatter::formatDateTime($acknowledgement->set_time)),
+            new HorizontalKeyValue(
+                t('Set on'),
+                DateFormatter::formatDateTime($acknowledgement->set_time->getTimestamp())
+            ),
             new HorizontalKeyValue(t('Author'), $acknowledgement->author
                 ? [new Icon('user'), $acknowledgement->author]
                 : new EmptyState(t('n. a.'))),
@@ -511,7 +546,7 @@ class EventDetail extends BaseHtmlElement
             $eventInfo[] = new HorizontalKeyValue(
                 t('Expires On'),
                 $acknowledgement->expire_time
-                ? DateFormatter::formatDateTime($acknowledgement->expire_time)
+                ? DateFormatter::formatDateTime($acknowledgement->expire_time->getTimestamp())
                 : new EmptyState(t('Never'))
             );
             $eventInfo[] = new HorizontalKeyValue(t('Sticky'), isset($acknowledgement->is_sticky)
@@ -523,7 +558,11 @@ class EventDetail extends BaseHtmlElement
         } else {
             $eventInfo[] = new HorizontalKeyValue(
                 t('Cleared on'),
-                DateFormatter::formatDateTime($acknowledgement->clear_time ?: $this->event->event_time)
+                DateFormatter::formatDateTime(
+                    $acknowledgement->clear_time
+                        ? $acknowledgement->clear_time->getTimestamp()
+                        : $this->event->event_time->getTimestamp()
+                )
             );
             if ($acknowledgement->cleared_by) {
                 $eventInfo[] = new HorizontalKeyValue(
@@ -535,12 +574,12 @@ class EventDetail extends BaseHtmlElement
                 if ($acknowledgement->expire_time) {
                     $now = (new DateTime())->setTimezone(new DateTimeZone('UTC'));
                     $expiresOn = clone $now;
-                    $expiresOn->setTimestamp($acknowledgement->expire_time);
+                    $expiresOn->setTimestamp($acknowledgement->expire_time->getTimestamp());
                     if ($now <= $expiresOn) {
                         $expired = true;
                         $eventInfo[] = new HorizontalKeyValue(t('Removal Reason'), t(
                             'The acknowledgement expired on %s',
-                            DateFormatter::formatDateTime($acknowledgement->expire_time)
+                            DateFormatter::formatDateTime($acknowledgement->expire_time->getTimestamp())
                         ));
                     }
                 }
