@@ -10,6 +10,7 @@ use Icinga\Application\Hook;
 use Icinga\Application\Hook\GrapherHook;
 use Icinga\Application\Icinga;
 use Icinga\Application\Logger;
+use Icinga\Application\Web;
 use Icinga\Date\DateFormatter;
 use Icinga\Exception\IcingaException;
 use Icinga\Module\Icingadb\Common\Auth;
@@ -19,6 +20,7 @@ use Icinga\Module\Icingadb\Common\Icons;
 use Icinga\Module\Icingadb\Common\Links;
 use Icinga\Module\Icingadb\Common\Macros;
 use Icinga\Module\Icingadb\Compat\CompatHost;
+use Icinga\Module\Icingadb\Compat\CompatService;
 use Icinga\Module\Icingadb\Model\CustomvarFlat;
 use Icinga\Module\Icingadb\Web\Navigation\Action;
 use Icinga\Module\Icingadb\Widget\MarkdownText;
@@ -31,12 +33,12 @@ use Icinga\Module\Icingadb\Model\User;
 use Icinga\Module\Icingadb\Model\Usergroup;
 use Icinga\Module\Icingadb\Util\PluginOutput;
 use Icinga\Module\Icingadb\Widget\ItemList\DowntimeList;
-use Icinga\Module\Icingadb\Widget\EmptyState;
-use Icinga\Module\Icingadb\Widget\StateChange;
+use Icinga\Module\Icingadb\Widget\ShowMore;
+use ipl\Web\Widget\CopyToClipboard;
+use ipl\Web\Widget\EmptyState;
 use ipl\Web\Widget\HorizontalKeyValue;
 use Icinga\Module\Icingadb\Widget\ItemList\CommentList;
 use Icinga\Module\Icingadb\Widget\PluginOutputContainer;
-use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Widget\TagList;
 use Icinga\Module\Monitoring\Hook\DetailviewExtensionHook;
 use Icinga\Web\Navigation\Navigation;
@@ -109,7 +111,7 @@ class ObjectDetail extends BaseHtmlElement
 
         $info[] = new HorizontalKeyValue(
             t('Last State Change'),
-            DateFormatter::formatDateTime($this->object->state->last_state_change)
+            DateFormatter::formatDateTime($this->object->state->last_state_change->getTimestamp())
         );
 
         return [
@@ -131,8 +133,10 @@ class ObjectDetail extends BaseHtmlElement
             $item->setObject($this->object);
         }
 
+        $monitoringInstalled = Icinga::app()->getModuleManager()->hasInstalled('monitoring');
+        $obj = $monitoringInstalled ? $this->compatObject() : $this->object;
         foreach ($this->object->action_url->first()->action_url ?? [] as $url) {
-            $url = $this->expandMacros($url, $this->object);
+            $url = $this->expandMacros($url, $obj);
             $navigation->addItem(
                 Html::wantHtml([
                     // Add warning to links that open in new tabs, as recommended by WCAG20 G201
@@ -319,8 +323,10 @@ class ObjectDetail extends BaseHtmlElement
         $navigation = new Navigation();
         $notes = trim($this->object->notes);
 
+        $monitoringInstalled = Icinga::app()->getModuleManager()->hasInstalled('monitoring');
+        $obj = $monitoringInstalled ? $this->compatObject() : $this->object;
         foreach ($this->object->notes_url->first()->notes_url ?? [] as $url) {
-            $url = $this->expandMacros($url, $this->object);
+            $url = $this->expandMacros($url, $obj);
             $navigation->addItem(
                 Html::wantHtml([
                     // Add warning to links that open in new tabs, as recommended by WCAG20 G201
@@ -418,6 +424,7 @@ class ObjectDetail extends BaseHtmlElement
             $pluginOutput = new EmptyState(t('Output unavailable.'));
         } else {
             $pluginOutput = new PluginOutputContainer(PluginOutput::fromObject($this->object));
+            CopyToClipboard::attachTo($pluginOutput);
         }
 
         return [
@@ -481,8 +488,10 @@ class ObjectDetail extends BaseHtmlElement
             }
 
             try {
+                /** @var Web $app */
+                $app = Icinga::app();
                 $renderedExtension = $extension
-                    ->setView(Icinga::app()->getViewRenderer()->view)
+                    ->setView($app->getViewRenderer()->view)
                     ->getHtmlForObject($this->compatObject());
 
                 $extensionHtml = new HtmlElement(
@@ -545,6 +554,7 @@ class ObjectDetail extends BaseHtmlElement
             );
         }
 
+        $userQuery = null;
         if ($this->isPermittedRoute('users')) {
             $userQuery = User::on($this->getDb());
             $userQuery->filter($objectFilter);
@@ -562,7 +572,7 @@ class ObjectDetail extends BaseHtmlElement
             $usergroupQuery = Usergroup::on($this->getDb());
             $usergroupQuery->filter($objectFilter);
             $this->applyRestrictions($usergroupQuery);
-            if ($groupBy) {
+            if ($groupBy && $userQuery !== null) {
                 $userQuery->getSelectBase()->groupBy(['usergroup.id']);
             }
 
@@ -579,6 +589,7 @@ class ObjectDetail extends BaseHtmlElement
         $customvarFlat = $this->object->customvar_flat;
         if (! $customvarFlat instanceof ResultSet) {
             $this->applyRestrictions($customvarFlat);
+            $customvarFlat->withColumns(['customvar.name', 'customvar.value']);
             $this->object->customvar_flat = $customvarFlat->execute();
         }
     }
