@@ -5,7 +5,6 @@
 namespace Icinga\Module\Icingadb\Widget\ItemList;
 
 use Icinga\Date\DateFormatter;
-use Icinga\Module\Icingadb\Common\BaseListItem;
 use Icinga\Module\Icingadb\Common\HostLink;
 use Icinga\Module\Icingadb\Common\Icons;
 use Icinga\Module\Icingadb\Common\Links;
@@ -15,12 +14,14 @@ use Icinga\Module\Icingadb\Common\ServiceLink;
 use Icinga\Module\Icingadb\Common\TicketLinks;
 use Icinga\Module\Icingadb\Model\Downtime;
 use Icinga\Module\Icingadb\Widget\MarkdownLine;
+use ipl\Html\Attributes;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
 use ipl\Html\HtmlElement;
 use ipl\Html\TemplateString;
 use ipl\Html\Text;
 use ipl\Stdlib\Filter;
+use ipl\Web\Common\BaseListItem;
 use ipl\Web\Widget\Icon;
 use ipl\Web\Widget\Link;
 
@@ -53,20 +54,20 @@ abstract class BaseDowntimeListItem extends BaseListItem
     /** @var int Downtime start time */
     protected $startTime;
 
-    protected function init()
+    protected function init(): void
     {
         if ($this->item->is_flexible && $this->item->is_in_effect) {
-            $this->startTime = $this->item->start_time;
-            $this->endTime = $this->item->end_time;
+            $this->startTime = $this->item->start_time->getTimestamp();
+            $this->endTime = $this->item->end_time->getTimestamp();
         } else {
-            $this->startTime = $this->item->scheduled_start_time;
-            $this->endTime = $this->item->scheduled_end_time;
+            $this->startTime = $this->item->scheduled_start_time->getTimestamp();
+            $this->endTime = $this->item->scheduled_end_time->getTimestamp();
         }
 
         $this->currentTime = time();
 
         $this->isActive = $this->item->is_in_effect
-            || $this->item->is_flexible && $this->item->scheduled_start_time <= $this->currentTime;
+            || $this->item->is_flexible && $this->item->scheduled_start_time->getTimestamp() <= $this->currentTime;
 
         $until = ($this->isActive ? $this->endTime : $this->startTime) - $this->currentTime;
         $this->duration = explode(' ', DateFormatter::formatDuration(
@@ -86,28 +87,22 @@ abstract class BaseDowntimeListItem extends BaseListItem
 
     protected function createProgress(): BaseHtmlElement
     {
-        $ref = floor(
-            (float) ($this->currentTime - $this->startTime)
-            / (float) ($this->endTime - $this->startTime)
-            * 100
-        );
-
-        $progress = Html::tag(
+        return new HtmlElement(
             'div',
-            ['class' => 'progress'],
-            Html::tag(
+            Attributes::create([
+                'class' => 'progress',
+                'data-animate-progress' => true,
+                'data-start-time' => $this->startTime,
+                'data-end-time' => $this->endTime
+            ]),
+            new HtmlElement(
                 'div',
-                [
-                    'class' => 'progress-bar',
-                    'style' => sprintf('width: %F%%', $ref)
-                ]
+                Attributes::create(['class' => 'bar'])
             )
         );
-
-        return $progress;
     }
 
-    protected function assembleCaption(BaseHtmlElement $caption)
+    protected function assembleCaption(BaseHtmlElement $caption): void
     {
         $markdownLine = new MarkdownLine($this->createTicketLinks($this->item->comment));
         $caption->getAttributes()->add($markdownLine->getAttributes());
@@ -122,7 +117,7 @@ abstract class BaseDowntimeListItem extends BaseListItem
         )->addFrom($markdownLine);
     }
 
-    protected function assembleTitle(BaseHtmlElement $title)
+    protected function assembleTitle(BaseHtmlElement $title): void
     {
         if ($this->getObjectLinkDisabled()) {
             $link = null;
@@ -169,7 +164,7 @@ abstract class BaseDowntimeListItem extends BaseListItem
         }
     }
 
-    protected function assembleVisual(BaseHtmlElement $visual)
+    protected function assembleVisual(BaseHtmlElement $visual): void
     {
         $dateTime = DateFormatter::formatDateTime($this->endTime);
 
@@ -196,9 +191,9 @@ abstract class BaseDowntimeListItem extends BaseListItem
         }
     }
 
-    protected function createTimestamp()
+    protected function createTimestamp(): ?BaseHtmlElement
     {
-        $dateTime = DateFormatter::formatDateTime($this->endTime);
+        $dateTime = DateFormatter::formatDateTime($this->isActive ? $this->endTime : $this->startTime);
 
         return Html::tag(
             'time',
