@@ -10,7 +10,7 @@ class CommentListItemMinimal extends BaseCommentListItem
 {
     use ListItemMinimalLayout;
 
-    protected function init()
+    protected function init(): void
     {
         parent::init();
 
