@@ -4,13 +4,14 @@
 
 namespace Icinga\Module\Icingadb\Widget\ItemList;
 
-use Icinga\Module\Icingadb\Common\BaseItemList;
 use Icinga\Module\Icingadb\Common\CaptionDisabled;
+use Icinga\Module\Icingadb\Common\DetailActions;
 use Icinga\Module\Icingadb\Common\Links;
 use Icinga\Module\Icingadb\Common\NoSubjectLink;
 use Icinga\Module\Icingadb\Common\ObjectLinkDisabled;
 use Icinga\Module\Icingadb\Common\TicketLinks;
 use Icinga\Module\Icingadb\Common\ViewMode;
+use ipl\Web\Common\BaseItemList;
 use ipl\Web\Url;
 
 class DowntimeList extends BaseItemList
@@ -20,6 +21,7 @@ class DowntimeList extends BaseItemList
     use ObjectLinkDisabled;
     use ViewMode;
     use TicketLinks;
+    use DetailActions;
 
     protected $defaultAttributes = ['class' => 'downtime-list'];
 
@@ -31,13 +33,16 @@ class DowntimeList extends BaseItemList
 
         if ($viewMode === 'minimal') {
             return DowntimeListItemMinimal::class;
+        } elseif ($viewMode === 'detailed') {
+            $this->removeAttribute('class', 'default-layout');
         }
 
         return DowntimeListItem::class;
     }
 
-    protected function init()
+    protected function init(): void
     {
+        $this->initializeDetailActions();
         $this->setMultiselectUrl(Links::downtimesDetails());
         $this->setDetailUrl(Url::fromPath('icingadb/downtime'));
     }
